@@ -1,6 +1,7 @@
 import collections
 
 from torm.utl.Config import config
+from torm.utl.Utl import to_snake_name
 from torm.field import *
 from torm.builder import MongoBuilder, MysqlBuilder
 from torm.connection import MongoConnection, MysqlConnection
@@ -28,7 +29,6 @@ class ModelMetaclass(type):
         bases:父类
         attrs:类的所有属性字典
         '''
-
         if name == 'Model':
             return type.__new__(cls, name, bases, attrs)  # 返回Model类型
 
@@ -82,7 +82,7 @@ class ModelMetaclass(type):
         # 表名
         __config['table'] = attrs.get(
             "__tablename__",
-            name.lower()
+            to_snake_name(name)
         )
 
         # 数据库连接参数
@@ -91,7 +91,8 @@ class ModelMetaclass(type):
         __config['charset'] = config.env(env_name)('TORM_CHARSET')
 
         # 数据库用户名和密码配置
-        if db_type == "mysql":
+        auth = config.env(env_name)("TORM_AUTH", default="off")
+        if auth == "on":
             __config['user'] = config.env(env_name)('TORM_USER')
             __config['password'] = config.env(env_name)('TORM_PASSWORD')
 
